library(shiny)

spc <- paste("&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;
              &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;
              &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;")

shinyServer(function(input, output) {

   
   output$text <- renderText({
      if(input$which=="No") {   
        if(is.na(input$low)) 
            txt <- paste("<h3>",spc,"P( X < ",input$high,") = ",
                round(pnorm(input$high,input$mu,input$sigma),4),"</h3>")
        if(is.na(input$high))         
            txt <- paste("<h3>",spc,"P( X > ",input$low,") = ",
                round(1-pnorm(input$low,input$mu,input$sigma),4),"</h3>")
        if(!is.na(input$low*input$high))
            txt <- paste("<h3>",spc,"P(",input$low," < X < ",input$high,") = ",
                round(pnorm(input$high,input$mu,input$sigma)-pnorm(input$low,input$mu,input$sigma),4),"</h3>")
      }
      else {
          if(input$gl=="P(X<x)") 
            txt <- paste("<h3>",spc,"P(X&lt;x) =",input$p,", so x =  ",
                round(qnorm(input$p,input$mu,input$sigma),1),"</h3>")
          else      
            txt <- paste("<h3>",spc,"P(X&gt;x) =",input$p,", so x =  ",
                round(qnorm(1-input$p,input$mu,input$sigma),1),"</h3>")      
      }
      txt        

   })        
   
    
   output$plot <- renderPlot({
        x <- seq(input$mu-3*input$sigma,input$mu+3*input$sigma,length=250)
        y <- dnorm(x,input$mu,input$sigma)
        plot(x,y,xlab="x",ylab="y",type="l",lwd=2)
        if(input$which=="No") {
            if(is.na(input$low)) low <- x[1]
            else low <- input$low
            if(is.na(input$high)) high <- x[250]
            else high <- input$high
        }
        else {
            if(input$gl=="P(X<x)") {
                low <- x[1]
                high <- qnorm(input$p,input$mu,input$sigma)
            }
            else {
                low <- qnorm(1-input$p,input$mu,input$sigma)
                high <- x[250]
            }
        }        
                
        I <- c(1:250)[x>low & x<high]
        x <- x[I]
        y <- y[I]

        polygon(c(x,rev(x)),c(rep(0,length(x)),rev(y)),col="blue")
   })
           
   output$appinfo <- renderText({ 
      HTML("<br>&nbsp;<br>&nbsp;<br>&nbsp;<br>
      <a target=\"_blank\" href=\"http://academic.uprm.edu/wrolke/myapps1.htm#normalprob\"><h4>What to do</h4></a><br>
      <h6>Written by: Dr. Wolfgang Rolke<br>Created: 1/15/2015</h6>")
      
  }) 
  
  output$explainText <- renderText({ 
        "<h5>Explanation: This demo illustrates the meaning of probabilities under the normal curve
        <p> For one sided areas move slider all the way to the left or right </h5>"
        
  })

})

